@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 package DBD::Oracle::GetInfo;
-# VERSION
+our $VERSION = '1.80'; # VERSION
 
 use DBD::Oracle ();
 
@@ -284,3 +284,46 @@ our %info = (
 1;
 
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBD::Oracle::GetInfo - Wrapper to get Oracle information
+
+=head1 VERSION
+
+version 1.80
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Tim Bunce <timb@cpan.org>
+
+=item *
+
+John Scoles <byterock@cpan.org>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=item *
+
+Martin J. Evans <mjevans@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2019, 2014, 2013, 2012, 2011, 2010 by Tim Bunce.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
